@@ -489,26 +489,26 @@ def test_calculate_all_CA_distances_invalid_residue_number(GS6_CP, NTL9_CP):
             assert index == -1
 
 
-# == SSProtein._SSProtein__residue_atom_com
-def test_residue_atom_com_new_resid_atom_name_None(GS6_CO, NTL9_CO):
+# == SSProtein._SSProtein__residue_atom_index
+def test_residue_atom_index_resid_atom_name_None(GS6_CO, NTL9_CO):
     trajs = [GS6_CO, NTL9_CO]
     for traj in trajs:
         # instantiate a new protein object since the previous reference is modified
         # elsewhere - hence our residue count will be off.
         protein = ssprotein.SSProtein(traj)
         unavailable_residue_index = protein.n_residues + 1
-        protein.residue_atom_com(unavailable_residue_index, atom_name=None)
+        protein.get_residue_atom_indices(unavailable_residue_index, atom_name=None)
         assert len(protein._SSProtein__residue_atom_table) == protein.n_residues + 1
 
 
-def test_residue_atom_com_new_resid_atom_name_CA(GS6_CO, NTL9_CO):
+def test_residue_atom_index_new_resid_atom_name_CA(GS6_CO, NTL9_CO):
     trajs = [GS6_CO, NTL9_CO]
     for traj in trajs:
         # instantiate a new protein object since the previous reference is modified
         # elsewhere - hence our residue count will be off.
         protein = ssprotein.SSProtein(traj)
         unavailable_residue_index = protein.n_residues + 1
-        protein.residue_atom_com(unavailable_residue_index, atom_name='CA')
+        protein.get_residue_atom_indices(unavailable_residue_index, atom_name='CA')
         assert len(protein._SSProtein__residue_atom_table) == protein.n_residues + 1
 
 
@@ -804,3 +804,31 @@ def test_get_site_accessibility_residue_names(GS6_CP, NTL9_CP, cta_protein_helpe
         protein = cta_protein_helper.lengthen_protein_trajectory(protein_obj, num_copies)
 
         protein.get_site_accessibility(residue_names, mode='residue_type')
+
+
+def test_get_angles_1(GS6_CP, NTL9_CP):
+
+    assert len(GS6_CP.get_angles('phi')[0]) == 6
+    assert GS6_CP.get_angles('phi')[0][0][0] == 'ACE1-C'
+    assert GS6_CP.get_angles('phi')[0][5][3] == 'SER7-C'
+    assert np.isclose(GS6_CP.get_angles('phi')[1][5][3], -147.67358) 
+    assert np.isclose(GS6_CP.get_angles('phi')[1][5][0], -126.707436)
+    assert np.isclose(GS6_CP.get_angles('phi')[1][0][0], -157.64288)
+    assert np.isclose(GS6_CP.get_angles('psi')[1][0][0] , -41.66139)
+    assert np.isclose(GS6_CP.get_angles('psi')[1][2][0] , 150.39041)
+    assert np.isclose(GS6_CP.get_angles('psi')[1][3][3], -38.81799)
+    assert np.isclose(GS6_CP.get_angles('psi')[1][4][3] , -89.94062)
+
+    assert GS6_CP.get_angles('chi1')[0][0][3] == 'SER3-OG'
+    assert GS6_CP.get_angles('chi1')[0][0][2] == 'SER3-CB'
+    assert GS6_CP.get_angles('chi1')[0][0][1] == 'SER3-CA'
+    assert GS6_CP.get_angles('chi1')[0][0][0] == 'SER3-N'
+
+    assert len(NTL9_CP.get_angles('phi')[0]) == 55
+    assert len(NTL9_CP.get_angles('psi')[0]) == 55
+    assert len(NTL9_CP.get_angles('omega')[0]) == 55
+    assert len(NTL9_CP.get_angles('chi1')[0]) == 44
+    assert len(NTL9_CP.get_angles('chi2')[0]) == 40
+    assert len(NTL9_CP.get_angles('chi3')[0]) == 21
+    assert len(NTL9_CP.get_angles('chi4')[0]) == 12
+    assert len(NTL9_CP.get_angles('chi5')[0]) == 1
